==> apache-camel-3.18.3-src.zip: apache-camel-3.18.3/core/camel-core/src/test/java/org/apache/camel/processor/LogEipBodyWithSimpleTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor;

import org.apache.camel.CamelContext;
import org.apache.camel.ContextTestSupport;
import org.apache.camel.ExtendedCamelContext;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;

public class LogEipBodyWithSimpleTest extends ContextTestSupport {

    private String msg;

    @Override
    protected CamelContext createCamelContext() throws Exception {
        CamelContext context = super.createCamelContext();
        context.adapt(ExtendedCamelContext.class).addLogListener((exchange, camelLogger, message) -> {
            msg = message;
            return message;
        });
        return context;
    }

    @Test
    public void testLogEip() throws Exception {
        template.sendBody("direct:start", null);

        assertEquals("Response from API is ==> REAL DATA", msg);
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("direct:start")
                        .setBody(constant("REAL DATA"))
                        .setProperty("body", constant("hello"))
                        .log("Response from API is ==> ${body}");
            }
        };
    }
}

==> apache-camel-4.14.4-src.zip: apache-camel-4.14.4/core/camel-core/src/test/java/org/apache/camel/processor/LogEipBodyWithSimpleTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor;

import org.apache.camel.CamelContext;
import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;

public class LogEipBodyWithSimpleTest extends ContextTestSupport {

    private String msg;

    @Override
    protected CamelContext createCamelContext() throws Exception {
        CamelContext context = super.createCamelContext();
        context.getCamelContextExtension().addLogListener((exchange, camelLogger, message) -> {
            msg = message;
            return message;
        });
        return context;
    }

    @Test
    public void testLogEip() {
        template.sendBody("direct:start", null);

        assertEquals("Response from API is ==> REAL DATA", msg);
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                from("direct:start")
                        .setBody(constant("REAL DATA"))
                        .setProperty("body", constant("hello"))
                        .log("Response from API is ==> ${body}");
            }
        };
    }
}
